Changelog
=========

Version 2.0.0
-------------

* Add support for Python 3.4 and 4.5 and drop support for Python < 2.7;
  add support for Django 1.9 and drop support for Django < 1.8
  (Matt Terry)

Version 1.2.8
-------------
* Use json package directly (Max Lynch)

Version 1.2.7
-------------
* Add support for encryption (Jeremy A. Johnson)
* Allow setting output format in widget decorator (Rob Hudson)

Version 1.2.6
-------------
* Allow number widget to return list of dicts (Arthur Furlan)

Version 1.2.5
-------------
* Add support for the "prefix" parameter (Arthur Furlan)

Version 1.2.4
-------------
* Add "Content-Type" header (Arthur Furlan)

Version 1.2.3
-------------
* Fix KeyError bug in auto-scaling code (Ben Belchak)

Version 1.2.2
-------------
* Fix comparative bar on bullet graphs (Rod Begbie)

Version 1.2.1
-------------
* Fix unicode handling (Éric St-Jean)

Version 1.2.0
-------------
* Add *bullet* widget decorator (Hedley Roos)

Version 1.1.0
-------------
* Add *funnel* widget decorator (Simon de Haan)

Version 1.0.0
-------------
* No changes from 0.2.1

Version 0.2.1
-------------
* Fix API key detection

Version 0.2.0
-------------
* Rename widget decorators

Version 0.1.0
-------------
* First release, split off from django-analytical_.

.. _django-analytical: http://pypi.python.org/pypi/django-analytical
